/* Copyright (c) 1996, 1997 Prominence Dot Com, Inc.        *
 * See the file legal.txt in the txt directory for details. */

package prominence.msg;

import java.io.*;

/**
 * A <tt>MessageInput</tt> that attaches to an existing <tt>MessageInput</tt>
 * and strips the routing header from each message that is received.
 * <p>The routing header is made publicly accessible in the <tt>target</tt>
 * variable.
 *
 * @version 1.0 1 Nov 1996
 * @author Merlin Hughes
 * @see prominence.msg.RoutingOutputStream
 */
public class RoutingInputStream extends MessageInput {
  /**
   * The routing list from the most recently received message.
   */
  public String[] target;
  /**
   * The <tt>MessageInput</tt> to which this is attached.
   */
  protected MessageInput i;

  /**
   * Creates a new <tt>RoutingInputStream</tt>.
   * @param i The <tt>MessageInput</tt> from which messages should be received
   */
  public RoutingInputStream (MessageInput i) {
    super (i);
    this.i = i;
  }

  /**
   * Receives a new message from <tt>i</tt> and strips the routing header.
   * The routing list is accessible in the <tt>target</tt> variable; the
   * contents of the message can be read through the usual superclass
   * <tt>read()</tt> methods.
   * @exception IOException Occurs if there is a problem receiving a message
   * or extracting the routing list.
   */
  public void receive () throws IOException {
    i.receive ();
    int n = i.readInt ();
    if (n < 0)
      target = null;
    else {
      target = new String[n];
      for (int j = 0; j < n; ++ j)
        target[j] = i.readUTF ();
    }
  }
}